==> openshift-model-monitoring-5.12.1-sources.jar: io/fabric8/openshift/api/model/monitoring/v1/AlertmanagerBuilder.java <==
package io.fabric8.openshift.api.model.monitoring.v1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Object;
import java.lang.Boolean;
public class AlertmanagerBuilder extends io.fabric8.openshift.api.model.monitoring.v1.AlertmanagerFluentImpl<io.fabric8.openshift.api.model.monitoring.v1.AlertmanagerBuilder> implements io.fabric8.kubernetes.api.builder.VisitableBuilder<io.fabric8.openshift.api.model.monitoring.v1.Alertmanager,io.fabric8.openshift.api.model.monitoring.v1.AlertmanagerBuilder>{
  public AlertmanagerBuilder() {
    this(false);
  }
  public AlertmanagerBuilder(java.lang.Boolean validationEnabled) {
    this(new Alertmanager(), validationEnabled);
  }
  public AlertmanagerBuilder(io.fabric8.openshift.api.model.monitoring.v1.AlertmanagerFluent<?> fluent) {
    this(fluent, false);
  }
  public AlertmanagerBuilder(io.fabric8.openshift.api.model.monitoring.v1.AlertmanagerFluent<?> fluent,java.lang.Boolean validationEnabled) {
    this(fluent, new Alertmanager(), validationEnabled);
  }
  public AlertmanagerBuilder(io.fabric8.openshift.api.model.monitoring.v1.AlertmanagerFluent<?> fluent,io.fabric8.openshift.api.model.monitoring.v1.Alertmanager instance) {
    this(fluent, instance, false);
  }
  public AlertmanagerBuilder(io.fabric8.openshift.api.model.monitoring.v1.AlertmanagerFluent<?> fluent,io.fabric8.openshift.api.model.monitoring.v1.Alertmanager instance,java.lang.Boolean validationEnabled) {
    this.fluent = fluent; 
    fluent.withApiVersion(instance.getApiVersion()); 
    fluent.withKind(instance.getKind()); 
    fluent.withMetadata(instance.getMetadata()); 
    fluent.withSpec(instance.getSpec()); 
    fluent.withStatus(instance.getStatus()); 
    fluent.withAdditionalProperties(instance.getAdditionalProperties());

    this.validationEnabled = validationEnabled; 
  }
  public AlertmanagerBuilder(io.fabric8.openshift.api.model.monitoring.v1.Alertmanager instance) {
    this(instance,false);
  }
  public AlertmanagerBuilder(io.fabric8.openshift.api.model.monitoring.v1.Alertmanager instance,java.lang.Boolean validationEnabled) {
    this.fluent = this; 
    this.withApiVersion(instance.getApiVersion()); 
    this.withKind(instance.getKind()); 
    this.withMetadata(instance.getMetadata()); 
    this.withSpec(instance.getSpec()); 
    this.withStatus(instance.getStatus()); 
    this.withAdditionalProperties(instance.getAdditionalProperties());

    this.validationEnabled = validationEnabled; 
  }
  io.fabric8.openshift.api.model.monitoring.v1.AlertmanagerFluent<?> fluent;
  java.lang.Boolean validationEnabled;
  public io.fabric8.openshift.api.model.monitoring.v1.Alertmanager build() {
    Alertmanager buildable = new Alertmanager(fluent.getApiVersion(),fluent.getKind(),fluent.getMetadata(),fluent.getSpec(),fluent.getStatus());
    buildable.setAdditionalProperties(fluent.getAdditionalProperties());
    return buildable;
  }
  public boolean equals(java.lang.Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    AlertmanagerBuilder that = (AlertmanagerBuilder) o;
    if (fluent != null &&fluent != this ? !fluent.equals(that.fluent) :that.fluent != null &&fluent != this ) return false;

    if (validationEnabled != null ? !validationEnabled.equals(that.validationEnabled) :that.validationEnabled != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(fluent,  validationEnabled,  super.hashCode());
  }
  
}

==> openshift-model-monitoring-6.5.1-sources.jar: io/fabric8/openshift/api/model/monitoring/v1/AlertmanagerBuilder.java <==
package io.fabric8.openshift.api.model.monitoring.v1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Boolean;
public class AlertmanagerBuilder extends AlertmanagerFluentImpl<AlertmanagerBuilder> implements VisitableBuilder<Alertmanager,AlertmanagerBuilder>{
  public AlertmanagerBuilder() {
    this(false);
  }
  public AlertmanagerBuilder(Boolean validationEnabled) {
    this(new Alertmanager(), validationEnabled);
  }
  public AlertmanagerBuilder(AlertmanagerFluent<?> fluent) {
    this(fluent, false);
  }
  public AlertmanagerBuilder(AlertmanagerFluent<?> fluent,Boolean validationEnabled) {
    this(fluent, new Alertmanager(), validationEnabled);
  }
  public AlertmanagerBuilder(AlertmanagerFluent<?> fluent,Alertmanager instance) {
    this(fluent, instance, false);
  }
  public AlertmanagerBuilder(AlertmanagerFluent<?> fluent,Alertmanager instance,Boolean validationEnabled) {
    this.fluent = fluent; 
    fluent.withApiVersion(instance.getApiVersion()); 
    fluent.withKind(instance.getKind()); 
    fluent.withMetadata(instance.getMetadata()); 
    fluent.withSpec(instance.getSpec()); 
    fluent.withStatus(instance.getStatus()); 
    fluent.withAdditionalProperties(instance.getAdditionalProperties());

    this.validationEnabled = validationEnabled; 
  }
  public AlertmanagerBuilder(Alertmanager instance) {
    this(instance,false);
  }
  public AlertmanagerBuilder(Alertmanager instance,Boolean validationEnabled) {
    this.fluent = this; 
    this.withApiVersion(instance.getApiVersion()); 
    this.withKind(instance.getKind()); 
    this.withMetadata(instance.getMetadata()); 
    this.withSpec(instance.getSpec()); 
    this.withStatus(instance.getStatus()); 
    this.withAdditionalProperties(instance.getAdditionalProperties());

    this.validationEnabled = validationEnabled; 
  }
  AlertmanagerFluent<?> fluent;
  Boolean validationEnabled;
  public Alertmanager build() {
    Alertmanager buildable = new Alertmanager(fluent.getApiVersion(),fluent.getKind(),fluent.getMetadata(),fluent.getSpec(),fluent.getStatus());
    buildable.setAdditionalProperties(fluent.getAdditionalProperties());
    return buildable;
  }
  
}
